@@ -71,8 +71,8 @@ typedef struct dbase_fld {
     char    name[11];                                           /*field name*/
     char    type;                                               /*field type*/
     /* A-T uses large data model but drop it for now */
-    char   *data_ptr;                         /*pointer into buffer*/
-    char   length;                                   /*field length*/
+    char   *data_ptr;                                           /*pointer into buffer*/
+    unsigned char length;                                       /*field length*/
     char   dec_point;                         /*field decimal point*/
     char   fill[14];
     } DBASE_FIELD;
